@@ -38,10 +38,7 @@ impl Default for DecompressionMatcherBuilder {
 impl DecompressionMatcherBuilder {
     /// Create a new builder for configuring a decompression matcher.
     pub fn new() -> DecompressionMatcherBuilder {
-        DecompressionMatcherBuilder {
-            commands: vec![],
-            defaults: true,
-        }
+        DecompressionMatcherBuilder { commands: vec![], defaults: true }
     }
 
     /// Build a matcher for determining how to decompress files.
@@ -49,12 +46,11 @@ impl DecompressionMatcherBuilder {
     /// If there was a problem compiling the matcher, then an error is
     /// returned.
     pub fn build(&self) -> Result<DecompressionMatcher, CommandError> {
-        let defaults =
-            if !self.defaults {
-                vec![]
-            } else {
-                default_decompression_commands()
-            };
+        let defaults = if !self.defaults {
+            vec![]
+        } else {
+            default_decompression_commands()
+        };
         let mut glob_builder = GlobSetBuilder::new();
         let mut commands = vec![];
         for decomp_cmd in defaults.iter().chain(&self.commands) {
@@ -93,17 +89,15 @@ impl DecompressionMatcherBuilder {
         program: P,
         args: I,
     ) -> &mut DecompressionMatcherBuilder
-    where P: AsRef<OsStr>,
-          I: IntoIterator<Item=A>,
-          A: AsRef<OsStr>,
+    where
+        P: AsRef<OsStr>,
+        I: IntoIterator<Item = A>,
+        A: AsRef<OsStr>,
     {
-
         let glob = glob.to_string();
         let bin = program.as_ref().to_os_string();
-        let args = args
-            .into_iter()
-            .map(|a| a.as_ref().to_os_string())
-            .collect();
+        let args =
+            args.into_iter().map(|a| a.as_ref().to_os_string()).collect();
         self.commands.push(DecompressionCommand { glob, bin, args });
         self
     }
@@ -354,6 +348,7 @@ fn default_decompression_commands() -> Vec<DecompressionCommand> {
     const ARGS_LZMA: &[&str] = &["xz", "--format=lzma", "-d", "-c"];
     const ARGS_BROTLI: &[&str] = &["brotli", "-d", "-c"];
     const ARGS_ZSTD: &[&str] = &["zstd", "-q", "-d", "-c"];
+    const ARGS_UNCOMPRESS: &[&str] = &["uncompress", "-c"];
 
     fn cmd(glob: &str, args: &[&str]) -> DecompressionCommand {
         DecompressionCommand {
@@ -378,5 +373,6 @@ fn default_decompression_commands() -> Vec<DecompressionCommand> {
         cmd("*.br", ARGS_BROTLI),
         cmd("*.zst", ARGS_ZSTD),
         cmd("*.zstd", ARGS_ZSTD),
+        cmd("*.Z", ARGS_UNCOMPRESS),
     ]
 }
