@@ -179,20 +179,18 @@ mod process;
 mod wtr;
 
 pub use decompress::{
-    DecompressionMatcher, DecompressionMatcherBuilder,
-    DecompressionReader, DecompressionReaderBuilder,
+    DecompressionMatcher, DecompressionMatcherBuilder, DecompressionReader,
+    DecompressionReaderBuilder,
 };
 pub use escape::{escape, escape_os, unescape, unescape_os};
-pub use human::{ParseSizeError, parse_human_readable_size};
+pub use human::{parse_human_readable_size, ParseSizeError};
 pub use pattern::{
-    InvalidPatternError,
-    pattern_from_os, pattern_from_bytes,
-    patterns_from_path, patterns_from_reader, patterns_from_stdin,
+    pattern_from_bytes, pattern_from_os, patterns_from_path,
+    patterns_from_reader, patterns_from_stdin, InvalidPatternError,
 };
 pub use process::{CommandError, CommandReader, CommandReaderBuilder};
 pub use wtr::{
-    StandardStream,
-    stdout, stdout_buffered_line, stdout_buffered_block,
+    stdout, stdout_buffered_block, stdout_buffered_line, StandardStream,
 };
 
 /// Returns true if and only if stdin is believed to be readable.
@@ -205,8 +203,8 @@ pub use wtr::{
 pub fn is_readable_stdin() -> bool {
     #[cfg(unix)]
     fn imp() -> bool {
-        use std::os::unix::fs::FileTypeExt;
         use same_file::Handle;
+        use std::os::unix::fs::FileTypeExt;
 
         let ft = match Handle::stdin().and_then(|h| h.as_file().metadata()) {
             Err(_) => return false,
