@@ -29,18 +29,19 @@ impl InvalidPatternError {
 }
 
 impl error::Error for InvalidPatternError {
-    fn description(&self) -> &str { "invalid pattern" }
+    fn description(&self) -> &str {
+        "invalid pattern"
+    }
 }
 
 impl fmt::Display for InvalidPatternError {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         write!(
             f,
-            "found invalid UTF-8 in pattern at byte offset {} \
-             (use hex escape sequences to match arbitrary bytes \
-             in a pattern, e.g., \\xFF): '{}'",
-            self.valid_up_to,
-            self.original,
+            "found invalid UTF-8 in pattern at byte offset {}: {} \
+             (disable Unicode mode and use hex escape sequences to match \
+             arbitrary bytes in a pattern, e.g., '(?-u)\\xFF')",
+            self.valid_up_to, self.original,
         )
     }
 }
@@ -63,10 +64,7 @@ pub fn pattern_from_os(pattern: &OsStr) -> Result<&str, InvalidPatternError> {
             .to_string_lossy()
             .find('\u{FFFD}')
             .expect("a Unicode replacement codepoint for invalid UTF-8");
-        InvalidPatternError {
-            original: escape_os(pattern),
-            valid_up_to: valid_up_to,
-        }
+        InvalidPatternError { original: escape_os(pattern), valid_up_to }
     })
 }
 
@@ -79,11 +77,9 @@ pub fn pattern_from_os(pattern: &OsStr) -> Result<&str, InvalidPatternError> {
 pub fn pattern_from_bytes(
     pattern: &[u8],
 ) -> Result<&str, InvalidPatternError> {
-    str::from_utf8(pattern).map_err(|err| {
-        InvalidPatternError {
-            original: escape(pattern),
-            valid_up_to: err.valid_up_to(),
-        }
+    str::from_utf8(pattern).map_err(|err| InvalidPatternError {
+        original: escape(pattern),
+        valid_up_to: err.valid_up_to(),
     })
 }
 
@@ -119,10 +115,7 @@ pub fn patterns_from_stdin() -> io::Result<Vec<String>> {
     let stdin = io::stdin();
     let locked = stdin.lock();
     patterns_from_reader(locked).map_err(|err| {
-        io::Error::new(
-            io::ErrorKind::Other,
-            format!("<stdin>:{}", err),
-        )
+        io::Error::new(io::ErrorKind::Other, format!("<stdin>:{}", err))
     })
 }
 
@@ -166,12 +159,10 @@ pub fn patterns_from_reader<R: io::Read>(rdr: R) -> io::Result<Vec<String>> {
                 patterns.push(pattern.to_string());
                 Ok(true)
             }
-            Err(err) => {
-                Err(io::Error::new(
-                    io::ErrorKind::Other,
-                    format!("{}: {}", line_number, err),
-                ))
-            }
+            Err(err) => Err(io::Error::new(
+                io::ErrorKind::Other,
+                format!("{}: {}", line_number, err),
+            )),
         }
     })?;
     Ok(patterns)
@@ -191,8 +182,8 @@ mod tests {
     #[test]
     #[cfg(unix)]
     fn os() {
-        use std::os::unix::ffi::OsStrExt;
         use std::ffi::OsStr;
+        use std::os::unix::ffi::OsStrExt;
 
         let pat = OsStr::from_bytes(b"abc\xFFxyz");
         let err = pattern_from_os(pat).unwrap_err();
